@@ -24,7 +24,7 @@
 
 using namespace KIdentityManagement;
 
-class Q_DECL_HIDDEN KIdentityManagement::SignaturePrivate
+class KIdentityManagement::SignaturePrivate
 {
 public:
     SignaturePrivate(Signature *qq)
@@ -203,7 +203,7 @@ void SignaturePrivate::cleanupImages()
 void SignaturePrivate::saveImages() const
 {
     if (inlinedHtml && !saveLocation.isEmpty()) {
-        for (const Signature::EmbeddedImagePtr &image : qAsConst(embeddedImages)) {
+        for (const Signature::EmbeddedImagePtr &image : std::as_const(embeddedImages)) {
             const QString location = saveLocation + QLatin1Char('/') + image->name;
             if (!image->image.save(location, "PNG")) {
                 qCWarning(KIDENTITYMANAGEMENT_LOG) << "Failed to save image" << location;
@@ -300,7 +300,7 @@ void SignaturePrivate::insertSignatureText(Signature::Placement placement,
 
     // We added the text of the signature above, now it is time to add the images as well.
     if (inlinedHtml) {
-        for (const Signature::EmbeddedImagePtr &image : qAsConst(embeddedImages)) {
+        for (const Signature::EmbeddedImagePtr &image : std::as_const(embeddedImages)) {
             textEdit->composerControler()->composerImages()->loadImage(image->image, image->name, image->name);
         }
     }
@@ -311,7 +311,7 @@ QDataStream &operator<<(QDataStream &stream, const KIdentityManagement::Signatur
     return stream << img->image << img->name;
 }
 
-QDataStream &operator>>(QDataStream &stream, KIdentityManagement::Signature::EmbeddedImagePtr &img)
+QDataStream &operator>>(QDataStream &stream, const KIdentityManagement::Signature::EmbeddedImagePtr &img)
 {
     return stream >> img->image >> img->name;
 }
@@ -354,10 +354,7 @@ Signature &Signature::operator=(const KIdentityManagement::Signature &that)
     return *this;
 }
 
-Signature::~Signature()
-{
-    delete d;
-}
+Signature::~Signature() = default;
 
 QString Signature::rawText(bool *ok) const
 {
